@@ -34,7 +34,7 @@
 
 using namespace Kerfuffle;
 
-K_PLUGIN_FACTORY_WITH_JSON(CliPluginFactory, "kerfuffle_cli7z.json", registerPlugin<CliPlugin>();)
+K_PLUGIN_CLASS_WITH_JSON(CliPlugin, "kerfuffle_cli7z.json")
 
 CliPlugin::CliPlugin(QObject *parent, const QVariantList & args)
         : CliInterface(parent, args)
@@ -92,68 +92,71 @@ void CliPlugin::setupCliProperties()
     m_cliProps->setProperty("compressionLevelSwitch", QStringLiteral("-mx=$CompressionLevel"));
     m_cliProps->setProperty("compressionMethodSwitch", QHash<QString,QVariant>{{QStringLiteral("application/x-7z-compressed"), QStringLiteral("-m0=$CompressionMethod")},
                                                                                {QStringLiteral("application/zip"), QStringLiteral("-mm=$CompressionMethod")}});
-    m_cliProps->setProperty("encryptionMethodSwitch", QHash<QString,QVariant>{{QStringLiteral("application/x-7z-compressed"), QStringLiteral()},
+    m_cliProps->setProperty("encryptionMethodSwitch", QHash<QString,QVariant>{{QStringLiteral("application/x-7z-compressed"), QString()},
                                                                               {QStringLiteral("application/zip"), QStringLiteral("-mem=$EncryptionMethod")}});
     m_cliProps->setProperty("multiVolumeSwitch", QStringLiteral("-v$VolumeSizek"));
-
-    m_cliProps->setProperty("passwordPromptPatterns", QStringList{QStringLiteral("Enter password \\(will not be echoed\\)")});
-    m_cliProps->setProperty("wrongPasswordPatterns", QStringList{QStringLiteral("Wrong password")});
     m_cliProps->setProperty("testPassedPatterns", QStringList{QStringLiteral("^Everything is Ok$")});
-    m_cliProps->setProperty("fileExistsPatterns", QStringList{QStringLiteral("^\\(Y\\)es / \\(N\\)o / \\(A\\)lways / \\(S\\)kip all / A\\(u\\)to rename all / \\(Q\\)uit\\? $"),
-                                                          QStringLiteral("^\\? \\(Y\\)es / \\(N\\)o / \\(A\\)lways / \\(S\\)kip all / A\\(u\\)to rename all / \\(Q\\)uit\\? $")});
-    m_cliProps->setProperty("fileExistsFileName", QStringList{QStringLiteral("^file \\./(.*)$"),
-                                                          QStringLiteral("^  Path:     \\./(.*)$")});
+    m_cliProps->setProperty("fileExistsFileNameRegExp", QStringList{QStringLiteral("^file \\./(.*)$"),
+                                                                    QStringLiteral("^  Path:     \\./(.*)$")});
     m_cliProps->setProperty("fileExistsInput", QStringList{QStringLiteral("Y"),   //Overwrite
                                                        QStringLiteral("N"),   //Skip
                                                        QStringLiteral("A"),   //Overwrite all
                                                        QStringLiteral("S"),   //Autoskip
                                                        QStringLiteral("Q")}); //Cancel
-    m_cliProps->setProperty("corruptArchivePatterns", QStringList{QStringLiteral("Unexpected end of archive"),
-                                                              QStringLiteral("Headers Error")});
-    m_cliProps->setProperty("diskFullPatterns", QStringList{QStringLiteral("No space left on device")});
     m_cliProps->setProperty("multiVolumeSuffix", QStringList{QStringLiteral("$Suffix.001")});
 }
 
+void CliPlugin::fixDirectoryFullName()
+{
+    if (m_currentArchiveEntry->isDir()) {
+        const QString directoryName = m_currentArchiveEntry->fullPath();
+        if (!directoryName.endsWith(QLatin1Char('/'))) {
+            m_currentArchiveEntry->setProperty("fullPath", QString(directoryName + QLatin1Char('/')));
+        }
+    }
+}
+
 bool CliPlugin::readListLine(const QString& line)
 {
     static const QLatin1String archiveInfoDelimiter1("--"); // 7z 9.13+
     static const QLatin1String archiveInfoDelimiter2("----"); // 7z 9.04
     static const QLatin1String entryInfoDelimiter("----------");
-    const QRegularExpression rxComment(QStringLiteral("Comment = .+$"));
 
-    const QRegularExpression rxListFailed(QStringLiteral("Open ERROR: Can not open the file as \\[7z\\] archive"));
-    if (rxListFailed.match(line).hasMatch()) {
+    if (line.startsWith(QLatin1String("Open ERROR: Can not open the file as [7z] archive"))) {
         emit error(i18n("Listing the archive failed."));
         return false;
     }
 
-    if (m_parseState == ParseStateTitle) {
+    const QRegularExpression rxVersionLine(QStringLiteral("^p7zip Version ([\\d\\.]+) .*$"));
+    QRegularExpressionMatch matchVersion;
 
-        const QRegularExpression rxVersionLine(QStringLiteral("^p7zip Version ([\\d\\.]+) .*$"));
-        QRegularExpressionMatch matchVersion = rxVersionLine.match(line);
+    switch (m_parseState) {
+    case ParseStateTitle:
+        matchVersion = rxVersionLine.match(line);
         if (matchVersion.hasMatch()) {
             m_parseState = ParseStateHeader;
             const QString p7zipVersion = matchVersion.captured(1);
             qCDebug(ARK) << "p7zip version" << p7zipVersion << "detected";
         }
+        break;
 
-    } else if (m_parseState == ParseStateHeader) {
-
-        if (line.startsWith(QStringLiteral("Listing archive:"))) {
+    case ParseStateHeader:
+        if (line.startsWith(QLatin1String("Listing archive:"))) {
             qCDebug(ARK) << "Archive name: "
-                     << line.right(line.size() - 16).trimmed();
+                         << line.right(line.size() - 16).trimmed();
         } else if ((line == archiveInfoDelimiter1) ||
                    (line == archiveInfoDelimiter2)) {
             m_parseState = ParseStateArchiveInformation;
-        } else if (line.contains(QStringLiteral("Error: "))) {
+        } else if (line.contains(QLatin1String("Error: "))) {
             qCWarning(ARK) << line.mid(7);
         }
+        break;
 
-    } else if (m_parseState == ParseStateArchiveInformation) {
-
+    case ParseStateArchiveInformation:
         if (line == entryInfoDelimiter) {
             m_parseState = ParseStateEntryInformation;
-        } else if (line.startsWith(QStringLiteral("Type = "))) {
+
+        } else if (line.startsWith(QLatin1String("Type = "))) {
             const QString type = line.mid(7).trimmed();
             qCDebug(ARK) << "Archive type: " << type;
 
@@ -178,20 +181,21 @@ bool CliPlugin::readListLine(const QString& line)
                 qCWarning(ARK) << "Unsupported archive type";
                 return false;
             }
-        } else if (line.startsWith(QStringLiteral("Volumes = "))) {
+
+        } else if (line.startsWith(QLatin1String("Volumes = "))) {
             m_numberOfVolumes = line.section(QLatin1Char('='), 1).trimmed().toInt();
 
-        } else if (line.startsWith(QStringLiteral("Method = "))) {
+        } else if (line.startsWith(QLatin1String("Method = "))) {
             QStringList methods = line.section(QLatin1Char('='), 1).trimmed().split(QLatin1Char(' '), QString::SkipEmptyParts);
             handleMethods(methods);
 
-        } else if (rxComment.match(line).hasMatch()) {
+        } else if (line.startsWith(QLatin1String("Comment = "))) {
             m_parseState = ParseStateComment;
             m_comment.append(line.section(QLatin1Char('='), 1) + QLatin1Char('\n'));
         }
+        break;
 
-    } else if (m_parseState == ParseStateComment) {
-
+    case ParseStateComment:
         if (line == entryInfoDelimiter) {
             m_parseState = ParseStateEntryInformation;
             if (!m_comment.trimmed().isEmpty()) {
@@ -202,49 +206,61 @@ bool CliPlugin::readListLine(const QString& line)
         } else {
             m_comment.append(line + QLatin1Char('\n'));
         }
+        break;
 
-    } else if (m_parseState == ParseStateEntryInformation) {
-
+    case ParseStateEntryInformation:
         if (m_isFirstInformationEntry) {
             m_isFirstInformationEntry = false;
             m_currentArchiveEntry = new Archive::Entry(this);
             m_currentArchiveEntry->compressedSizeIsSet = false;
         }
-        if (line.startsWith(QStringLiteral("Path = "))) {
+        if (line.startsWith(QLatin1String("Path = "))) {
             const QString entryFilename =
                 QDir::fromNativeSeparators(line.mid(7).trimmed());
             m_currentArchiveEntry->setProperty("fullPath", entryFilename);
-        } else if (line.startsWith(QStringLiteral("Size = "))) {
+
+        } else if (line.startsWith(QLatin1String("Size = "))) {
             m_currentArchiveEntry->setProperty("size", line.mid(7).trimmed());
-        } else if (line.startsWith(QStringLiteral("Packed Size = "))) {
+
+        } else if (line.startsWith(QLatin1String("Packed Size = "))) {
             // #236696: 7z files only show a single Packed Size value
             //          corresponding to the whole archive.
             if (m_archiveType != ArchiveType7z) {
                 m_currentArchiveEntry->compressedSizeIsSet = true;
                 m_currentArchiveEntry->setProperty("compressedSize", line.mid(14).trimmed());
             }
-        } else if (line.startsWith(QStringLiteral("Modified = "))) {
+
+        } else if (line.startsWith(QLatin1String("Modified = "))) {
             m_currentArchiveEntry->setProperty("timestamp", QDateTime::fromString(line.mid(11).trimmed(),
                                                                                   QStringLiteral("yyyy-MM-dd hh:mm:ss")));
-        } else if (line.startsWith(QStringLiteral("Attributes = "))) {
-            const QString attributes = line.mid(13).trimmed();
 
-            const bool isDirectory = attributes.startsWith(QLatin1Char('D'));
+        } else if (line.startsWith(QLatin1String("Folder = "))) {
+            const QString isDirectoryStr = line.mid(9).trimmed();
+            Q_ASSERT(isDirectoryStr == QStringLiteral("+") || isDirectoryStr == QStringLiteral("-"));
+            const bool isDirectory = isDirectoryStr.startsWith(QLatin1Char('+'));
             m_currentArchiveEntry->setProperty("isDirectory", isDirectory);
-            if (isDirectory) {
-                const QString directoryName =
-                    m_currentArchiveEntry->fullPath();
-                if (!directoryName.endsWith(QLatin1Char('/'))) {
-                    const bool isPasswordProtected = (line.at(12) == QLatin1Char('+'));
-                    m_currentArchiveEntry->setProperty("fullPath", QString(directoryName + QLatin1Char('/')));
-                    m_currentArchiveEntry->setProperty("isPasswordProtected", isPasswordProtected);
-                }
+            fixDirectoryFullName();
+
+        } else if (line.startsWith(QLatin1String("Attributes = "))) {
+            const QString attributes = line.mid(13).trimmed();
+            if (attributes.contains(QLatin1Char('D'))) {
+                m_currentArchiveEntry->setProperty("isDirectory", true);
+                fixDirectoryFullName();
             }
 
-            m_currentArchiveEntry->setProperty("permissions", attributes.mid(1));
-        } else if (line.startsWith(QStringLiteral("CRC = "))) {
+            if (attributes.contains(QLatin1Char('_'))) {
+                // Unix attributes
+                m_currentArchiveEntry->setProperty("permissions",
+                                                   attributes.mid(attributes.indexOf(QLatin1Char(' ')) + 1));
+            } else {
+                // FAT attributes
+                m_currentArchiveEntry->setProperty("permissions", attributes);
+            }
+
+        } else if (line.startsWith(QLatin1String("CRC = "))) {
             m_currentArchiveEntry->setProperty("CRC", line.mid(6).trimmed());
-        } else if (line.startsWith(QStringLiteral("Method = "))) {
+
+        } else if (line.startsWith(QLatin1String("Method = "))) {
             m_currentArchiveEntry->setProperty("method", line.mid(9).trimmed());
 
             // For zip archives we need to check method for each entry.
@@ -253,11 +269,12 @@ bool CliPlugin::readListLine(const QString& line)
                 handleMethods(methods);
             }
 
-        } else if (line.startsWith(QStringLiteral("Encrypted = ")) &&
+        } else if (line.startsWith(QLatin1String("Encrypted = ")) &&
                    line.size() >= 13) {
             m_currentArchiveEntry->setProperty("isPasswordProtected", line.at(12) == QLatin1Char('+'));
-        } else if (line.startsWith(QStringLiteral("Block = ")) ||
-                   line.startsWith(QStringLiteral("Version = "))) {
+
+        } else if (line.startsWith(QLatin1String("Block = ")) ||
+                   line.startsWith(QLatin1String("Version = "))) {
             m_isFirstInformationEntry = true;
             if (!m_currentArchiveEntry->fullPath().isEmpty()) {
                 emit entry(m_currentArchiveEntry);
@@ -267,6 +284,7 @@ bool CliPlugin::readListLine(const QString& line)
             }
             m_currentArchiveEntry = nullptr;
         }
+        break;
     }
 
     return true;
@@ -274,15 +292,13 @@ bool CliPlugin::readListLine(const QString& line)
 
 bool CliPlugin::readExtractLine(const QString &line)
 {
-    const QRegularExpression rxUnknownError(QStringLiteral("ERROR: E_FAIL"));
-    const QRegularExpression rxBadCRC(QStringLiteral("ERROR: CRC Failed"));
-
-    if (rxUnknownError.match(line).hasMatch()) {
+    if (line.startsWith(QLatin1String("ERROR: E_FAIL"))) {
         emit error(i18n("Extraction failed due to an unknown error."));
         return false;
     }
 
-    if (rxBadCRC.match(line).hasMatch()) {
+    if (line.startsWith(QLatin1String("ERROR: CRC Failed")) ||
+        line.startsWith(QLatin1String("ERROR: Headers Error"))) {
         emit error(i18n("Extraction failed due to one or more corrupt files. Any extracted files may be damaged."));
         return false;
     }
@@ -292,9 +308,8 @@ bool CliPlugin::readExtractLine(const QString &line)
 
 bool CliPlugin::readDeleteLine(const QString &line)
 {
-    QRegularExpression rx(QStringLiteral("Error: .+ is not supported archive"));
-
-    if (rx.match(line).hasMatch()) {
+    if (line.startsWith(QLatin1String("Error: ")) &&
+        line.endsWith(QLatin1String(" is not supported archive"))) {
         emit error(i18n("Delete operation failed. Try upgrading p7zip or disabling the p7zip plugin in the configuration dialog."));
         return false;
     }
@@ -332,4 +347,37 @@ void CliPlugin::handleMethods(const QStringList &methods)
     }
 }
 
+bool CliPlugin::isPasswordPrompt(const QString &line)
+{
+    return line.startsWith(QLatin1String("Enter password (will not be echoed):"));
+}
+
+bool CliPlugin::isWrongPasswordMsg(const QString &line)
+{
+    return line.contains(QLatin1String("Wrong password"));
+}
+
+bool CliPlugin::isCorruptArchiveMsg(const QString &line)
+{
+    return (line == QLatin1String("Unexpected end of archive") ||
+            line == QLatin1String("Headers Error"));
+}
+
+bool CliPlugin::isDiskFullMsg(const QString &line)
+{
+    return line.contains(QLatin1String("No space left on device"));
+}
+
+bool CliPlugin::isFileExistsMsg(const QString &line)
+{
+    return (line == QLatin1String("(Y)es / (N)o / (A)lways / (S)kip all / A(u)to rename all / (Q)uit? ") ||
+            line == QLatin1String("? (Y)es / (N)o / (A)lways / (S)kip all / A(u)to rename all / (Q)uit? "));
+}
+
+bool CliPlugin::isFileExistsFileName(const QString &line)
+{
+    return (line.startsWith(QLatin1String("file ./")) ||
+            line.startsWith(QLatin1String("  Path:     ./")));
+}
+
 #include "cliplugin.moc"
