@@ -33,7 +33,7 @@
 
     using namespace Kerfuffle;
 
-K_PLUGIN_FACTORY_WITH_JSON(CliPluginFactory, "kerfuffle_clirar.json", registerPlugin<CliPlugin>();)
+K_PLUGIN_CLASS_WITH_JSON(CliPlugin, "kerfuffle_clirar.json")
 
 CliPlugin::CliPlugin(QObject *parent, const QVariantList& args)
         : CliInterface(parent, args)
@@ -108,21 +108,14 @@ void CliPlugin::setupCliProperties()
     m_cliProps->setProperty("multiVolumeSwitch", QStringLiteral("-v$VolumeSizek"));
 
 
-    m_cliProps->setProperty("passwordPromptPatterns", QStringList{QStringLiteral("Enter password \\(will not be echoed\\) for")});
-    m_cliProps->setProperty("wrongPasswordPatterns", QStringList{QStringLiteral("password incorrect"),
-                                                             QStringLiteral("wrong password")});
     m_cliProps->setProperty("testPassedPatterns", QStringList{QStringLiteral("^All OK$")});
-    m_cliProps->setProperty("fileExistsPatterns", QStringList{QStringLiteral("^\\[Y\\]es, \\[N\\]o, \\[A\\]ll, n\\[E\\]ver, \\[R\\]ename, \\[Q\\]uit $")});
-    m_cliProps->setProperty("fileExistsFileName", QStringList{QStringLiteral("^(.+) already exists. Overwrite it"),  // unrar 3 & 4
-                                                          QStringLiteral("^Would you like to replace the existing file (.+)$")}); // unrar 5
+    m_cliProps->setProperty("fileExistsFileNameRegExp", QStringList{QStringLiteral("^(.+) already exists. Overwrite it"),  // unrar 3 & 4
+                                                                    QStringLiteral("^Would you like to replace the existing file (.+)$")}); // unrar 5
     m_cliProps->setProperty("fileExistsInput", QStringList{QStringLiteral("Y"),   //Overwrite
                                                        QStringLiteral("N"),   //Skip
                                                        QStringLiteral("A"),   //Overwrite all
                                                        QStringLiteral("E"),   //Autoskip
                                                        QStringLiteral("Q")}); //Cancel
-    m_cliProps->setProperty("corruptArchivePatterns", QStringList{QStringLiteral("Unexpected end of archive"),
-                                                              QStringLiteral("the file header is corrupt")});
-    m_cliProps->setProperty("diskFullPatterns", QStringList{QStringLiteral("No space left on device")});
 
     // rar will sometimes create multi-volume archives where first volume is
     // called name.part1.rar and other times name.part01.rar.
@@ -173,8 +166,7 @@ bool CliPlugin::readListLine(const QString &line)
 
 bool CliPlugin::handleUnrar5Line(const QString &line)
 {
-    const QRegularExpression rxVolume(QStringLiteral("Cannot find volume "));
-    if (rxVolume.match(line).hasMatch()) {
+    if (line.startsWith(QLatin1String("Cannot find volume "))) {
         emit error(i18n("Failed to find all archive volumes."));
         return false;
     }
@@ -182,11 +174,10 @@ bool CliPlugin::handleUnrar5Line(const QString &line)
     // Parses the comment field.
     if (m_parseState == ParseStateComment) {
 
-        // RegExp matching end of comment field.
-        // FIXME: Comment itself could also contain the Archive path string here.
-        QRegularExpression rxCommentEnd(QStringLiteral("^Archive: .+$"));
+        // "Archive: " is printed after the comment.
+        // FIXME: Comment itself could also contain the searched string.
 
-        if (rxCommentEnd.match(line).hasMatch()) {
+        if (line.startsWith(QLatin1String("Archive: "))) {
             m_parseState = ParseStateHeader;
             m_comment = m_comment.trimmed();
             m_linesComment = m_comment.count(QLatin1Char('\n')) + 1;
@@ -206,7 +197,7 @@ bool CliPlugin::handleUnrar5Line(const QString &line)
     else if (m_parseState == ParseStateHeader) {
 
         // "Details: " indicates end of header.
-        if (line.startsWith(QStringLiteral("Details: "))) {
+        if (line.startsWith(QLatin1String("Details: "))) {
             ignoreLines(1, ParseStateEntryDetails);
             if (line.contains(QLatin1String("volume"))) {
                 m_numberOfVolumes++;
@@ -269,9 +260,7 @@ void CliPlugin::handleUnrar5Entry()
     compressionRatio.chop(1); // Remove the '%'
     e->setProperty("ratio", compressionRatio);
 
-    QString time = m_unrar5Details.value(QStringLiteral("mtime"));
-    QDateTime ts = QDateTime::fromString(time, QStringLiteral("yyyy-MM-dd HH:mm:ss,zzz"));
-    e->setProperty("timestamp", ts);
+    e->setProperty("timestamp", QDateTime::fromString(m_unrar5Details.value(QStringLiteral("mtime")), QStringLiteral("yyyy-MM-dd HH:mm:ss,zzz")));
 
     bool isDirectory = (m_unrar5Details.value(QStringLiteral("type")) == QLatin1String("Directory"));
     e->setProperty("isDirectory", isDirectory);
@@ -287,7 +276,7 @@ void CliPlugin::handleUnrar5Entry()
         e->setProperty("version", compression.left(optionPos).trimmed());
     } else {
         // No method specified.
-        e->setProperty("method", QStringLiteral(""));
+        e->setProperty("method", QString());
         e->setProperty("version", compression);
     }
 
@@ -313,8 +302,7 @@ void CliPlugin::handleUnrar5Entry()
 
 bool CliPlugin::handleUnrar4Line(const QString &line)
 {
-    const QRegularExpression rxVolume(QStringLiteral("Cannot find volume "));
-    if (rxVolume.match(line).hasMatch()) {
+    if (line.startsWith(QLatin1String("Cannot find volume "))) {
         emit error(i18n("Failed to find all archive volumes."));
         return false;
     }
@@ -377,7 +365,7 @@ bool CliPlugin::handleUnrar4Line(const QString &line)
     else if (m_parseState == ParseStateHeader) {
 
         // Horizontal line indicates end of header.
-        if (line.startsWith(QStringLiteral("--------------------"))) {
+        if (line.startsWith(QLatin1String("--------------------"))) {
             m_parseState = ParseStateEntryFileName;
         } else if (line.startsWith(QLatin1String("Volume "))) {
             m_numberOfVolumes++;
@@ -412,7 +400,7 @@ bool CliPlugin::handleUnrar4Line(const QString &line)
 
         // The entries list ends with a horizontal line, followed by a
         // single summary line or, for multi-volume archives, another header.
-        if (line.startsWith(QStringLiteral("-----------------"))) {
+        if (line.startsWith(QLatin1String("-----------------"))) {
             m_parseState = ParseStateHeader;
             return true;
 
@@ -448,7 +436,7 @@ bool CliPlugin::handleUnrar4Line(const QString &line)
 
         // If we reach a horizontal line, then the previous line was not an
         // entry name, so go back to header.
-        if (line.startsWith(QStringLiteral("-----------------"))) {
+        if (line.startsWith(QLatin1String("-----------------"))) {
             m_parseState = ParseStateHeader;
             return true;
         }
@@ -561,8 +549,7 @@ bool CliPlugin::readExtractLine(const QString &line)
         return false;
     }
 
-    const QRegularExpression rxVolume(QStringLiteral("Cannot find volume "));
-    if (rxVolume.match(line).hasMatch()) {
+    if (line.startsWith(QLatin1String("Cannot find volume "))) {
         emit error(i18n("Failed to find all archive volumes."));
         return false;
     }
@@ -581,4 +568,37 @@ void CliPlugin::ignoreLines(int lines, ParseState nextState)
     m_parseState = nextState;
 }
 
+bool CliPlugin::isPasswordPrompt(const QString &line)
+{
+    return line.startsWith(QLatin1String("Enter password \\(will not be echoed\\) for"));
+}
+
+bool CliPlugin::isWrongPasswordMsg(const QString &line)
+{
+    return (line.contains(QLatin1String("password incorrect")) || line.contains(QLatin1String("wrong password")));
+}
+
+bool CliPlugin::isCorruptArchiveMsg(const QString &line)
+{
+    return (line == QLatin1String("Unexpected end of archive") ||
+            line.contains(QLatin1String("the file header is corrupt")) ||
+            line.endsWith(QLatin1String("checksum error")));
+}
+
+bool CliPlugin::isDiskFullMsg(const QString &line)
+{
+    return line.contains(QLatin1String("No space left on device"));
+}
+
+bool CliPlugin::isFileExistsMsg(const QString &line)
+{
+    return (line == QLatin1String("[Y]es, [N]o, [A]ll, n[E]ver, [R]ename, [Q]uit "));
+}
+
+bool CliPlugin::isFileExistsFileName(const QString &line)
+{
+    return (line.startsWith(QLatin1String("Would you like to replace the existing file ")) || // unrar 5
+            line.contains(QLatin1String(" already exists. Overwrite it"))); // unrar 3 & 4
+}
+
 #include "cliplugin.moc"
