@@ -39,6 +39,12 @@ public:
     bool readListLine(const QString &line) override;
     bool readExtractLine(const QString &line) override;
     bool hasBatchExtractionProgress() const override;
+    bool isPasswordPrompt(const QString &line) override;
+    bool isWrongPasswordMsg(const QString &line) override;
+    bool isCorruptArchiveMsg(const QString &line) override;
+    bool isDiskFullMsg(const QString &line) override;
+    bool isFileExistsMsg(const QString &line) override;
+    bool isFileExistsFileName(const QString &line) override;
 
 private:
 
